dot-check_domains_overlap: Check for domain overlap between treatment and functional...

.check_domains_overlapR Documentation

Check for domain overlap between treatment and functional outcome

Description

Emits a warning when the treatment and outcome share the same domain name and the domains numerically overlap, because the historical constraint (non-anticipativity) may be needed but is not enforced.

Usage

.check_domains_overlap(domain_t, name_t, domain_o, name_o)

Arguments

domain_t

Numeric c(a, b) treatment domain.

name_t

Character treatment domain name.

domain_o

Numeric c(a, b) outcome domain.

name_o

Character outcome domain name.


FPScausal documentation built on Aug. 9, 2026, 9:07 a.m.