| .check_domains_overlap | R Documentation |
Emits a warning when the treatment and outcome share the same domain name and the domains numerically overlap, because the historical constraint (non-anticipativity) may be needed but is not enforced.
.check_domains_overlap(domain_t, name_t, domain_o, name_o)
domain_t |
Numeric c(a, b) treatment domain. |
name_t |
Character treatment domain name. |
domain_o |
Numeric c(a, b) outcome domain. |
name_o |
Character outcome domain name. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.